@@ -505,6 +505,9 @@ gpk_log_add_item (PkTransactionPast *item)
 	else if (g_strcmp0 (cmdline, "/usr/libexec/pk-command-not-found") == 0)
 		/* TRANSLATORS: short name for the command not found plugin */
 		tool = _("Bash - Command Not Found");
+	else if (g_strcmp0 (cmdline, "/usr/libexec/gnome-settings-daemon") == 0)
+		/* TRANSLATORS: user friendly name for gnome-settings-dameon */
+		tool = _("GNOME Session");
 	else
 		tool = cmdline;
 
@@ -654,16 +657,6 @@ gpk_log_entry_filter_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_da
 	return FALSE;
 }
 
-/**
- * gpk_log_delete_event_cb:
- **/
-static gboolean
-gpk_log_delete_event_cb (GtkWidget *widget, GdkEvent *event, GtkApplication *application)
-{
-	g_application_release (G_APPLICATION (application));
-	return FALSE;
-}
-
 /**
  * gpk_log_button_close_cb:
  **/
@@ -720,10 +713,6 @@ gpk_log_startup_cb (GtkApplication *application, gpointer user_data)
 	/* set a size, as the screen allows */
 	gpk_window_set_size_request (window, 1200, 1200);
 
-	/* Get the main window quit */
-	g_signal_connect (window, "delete-event",
-			  G_CALLBACK (gpk_log_delete_event_cb), application);
-
 	/* if command line arguments are set, then setup UI */
 	if (filter != NULL) {
 		widget = GTK_WIDGET (gtk_builder_get_object (builder, "entry_package"));
